Summary:	Next generation initrd image generator
Name:		dracut
Version:	024
Release:	2
Group:		System/Base
License:	GPLv2+
URL:		https://dracut.wiki.kernel.org/
Source0:	http://www.kernel.org/pub/linux/utils/boot/dracut/%{name}-%{version}.tar.xz
Source3:	50-dracut-mandriva.conf
# (tpg) simple script to provide a backup for current working initrd file
Source4:	initrd-backup.sh
# (bor) mdv-specific fixes
Patch1000:	dracut-011-mdv.patch
# (bor) Restore original Mandriva behaviour of adding bootchart if RPM is installed.
Patch1001:	dracut-007-undisable_bootchart.patch
# (bor) compatibility with mkinitrd
Patch1002:	dracut-010-mkinitrd.patch
# (bor) Add support for KEYTABLE to dynamically determine whether to install UNICODE or non-UNICODE keymap version.
Patch1003:	dracut-007-aufs-mount.patch
# (anssi) handle gzip compressed KMS kernel modules
#Patch1004:	dracut-011-rosa-livecdfix.patch

#Patch1005:	dracut-013-ld.so.conf.workaround.patch
#Patch1006:	dracut-014-multipath-udev-rules.patch
#Patch1007:	dracut-018-check-for-tty-and-use-it.patch
#Patch1008:	dracut-018-do-not-remount-twice-disk-partitions.patch
#Patch1009:	dracut-018-install-var-run-and-var-lock.patch

### GIT PATCHES GOES HERE  ###
###

BuildRequires:	docbook-dtd45-xml
BuildRequires:	docbook-style-xsl
BuildRequires:	xsltproc
BuildRequires:	dash
BuildRequires:	bash
BuildRequires:	asciidoc

Provides:	mkinitrd-command
Requires(pre):	filesystem
Requires(pre):	coreutils
Requires:	udev
Requires:	util-linux-ng
%if %mdvver < 201200
Requires:	module-init-tools
%else
Requires:	kmod
%endif
Requires:	e2fsprogs
Requires:	cpio
Requires:	findutils
Requires:	binutils
Requires:	grep
Requires:	mktemp
Requires:	bash
Requires:	dash
Requires:	kbd
Requires:	tar
Requires:	gzip
Requires:	bzip2
Requires:	file
Requires:	bridge-utils
Requires:	initscripts
Requires:	bootloader-utils
Requires(pre):	rpm-helper
Requires(post,postun):	update-alternatives
Conflicts:	mkinitrd < 6.0.93-%manbo_mkrel 10
Conflicts:	nash < 6.0.93-%manbo_mkrel 11

Obsoletes:	dracut < 013

%description
Dracut contains tools to create a bootable initramfs for 2.6 Linux kernels.
Unlike existing implementations, dracut does hard-code as little as possible
into the initramfs. Dracut contains various modules which are driven by the
event-based udev. Having root on MD, DM, LVM2, LUKS is supported as well as
NFS, iSCSI, NBD, FCoE with the dracut-network package.

%prep
%setup -q
%apply_patches
# We don't want to strip dracut-install, that's debuginfo's job
sed -i -e 's,\$(strip),,g' install/Makefile

%build
%serverbuild_hardened
%make

%install
rm -rf %{buildroot}

%makeinstall_std \
	sbindir=/sbin \
	libdir=%{_prefix}/lib \
	bindir=%{_bindir} \
	sysconfdir=%{_sysconfdir} \
	systemdsystemunitdir=%{_unitdir} \
	mandir=%{_mandir}

install -m 644 %{SOURCE3} %{buildroot}%{_sysconfdir}/dracut.conf.d

%if %mdvver >= 201200
# (tpg) default image name in 2012 has changed
sed -i -e 's/welcome.png/backgorund.png/' %{buildroot}%{_prefix}/lib/dracut/modules.d/50plymouth/plymouth-populate-initrd.sh
%endif

# bluca remove patch backup files
find %{buildroot} -type f -name '*.orig' -exec rm {} \;
find %{buildroot} -type f -name '*~' -exec rm {} \;

# fix permission of module files
chmod +x %{buildroot}%{_prefix}/lib/dracut/modules.d/*/*.sh

mkdir -p %{buildroot}/boot/dracut
mkdir -p %{buildroot}%{_var}/lib/dracut/overlay
install -m 755 -d %{buildroot}%{_datadir}/dracut

mkdir -p %{buildroot}%{_sbindir}
mkdir -p %{buildroot}/sbin
mv %{buildroot}%{_bindir}/* %{buildroot}%{_sbindir}/

ln -s %{_sbindir}/dracut %{buildroot}%{_bindir}/dracut
ln -s %{_sbindir}/dracut %{buildroot}/sbin/dracut
ln -s %{_prefix}/lib/dracut/dracut-install %{buildroot}%{_sbindir}/dracut-install

mkdir -p %{buildroot}%{_localstatedir}/log
touch %{buildroot}%{_localstatedir}/log/dracut.log
mkdir -p %{buildroot}%{_sysconfdir}/logrotate.d
install -m 0644 dracut.logrotate %{buildroot}%{_sysconfdir}/logrotate.d/dracut_log

mv %{buildroot}%{_sbindir}/lsinitrd %{buildroot}%{_sbindir}/lsinitrd-dracut
mv %{buildroot}%{_sbindir}/mkinitrd %{buildroot}%{_sbindir}/mkinitrd-dracut

cat > README.urpmi << EOF
dracut is the default mkinitrd replacement in mandriva

If you relly want to use old mkinitrd instead of dracut run
update-alternatives --set mkinitrd /sbin/mkinitrd-mkinitrd
EOF

# rpmlint madness
chmod 755 %{buildroot}%{_prefix}/lib/dracut/modules.d/99aufs-mount/install

# (tpg) don't follow this usr madness
# systemctl sits in /bin, and it symlinks to /usr/bin
sed -i -e 's#/usr/bin/systemctl#/bin/systemctl#g' %{buildroot}%{_prefix}/lib/dracut/modules.d/98systemd/*.service
# (tpg) use real path for udevadm
sed -i -e 's#/usr/bin/udevadm#/sbin/udevadm#g' %{buildroot}%{_prefix}/lib/dracut/modules.d/98systemd/*.service

# (tpg) this conflicts with mkinitrd
rm -rf %{buildroot}%{_mandir}/man8/mkinitrd.8*

install -m755 %{SOURCE4} %{buildroot}%{_bindir}/initrd-backup.sh

%post
update-alternatives --install /sbin/mkinitrd mkinitrd %{_sbindir}/mkinitrd-dracut 110 || :
update-alternatives --install /sbin/lsinitrd lsinitrd %{_sbindir}/lsinitrd-dracut 110 || :

%postun
[ ! -e /usr/sbin/mkinitrd-dracut ] && update-alternatives --remove mkinitrd %{_sbindir}/mkinitrd-dracut || :
[ ! -e /usr/sbin/lsinitrd-dracut ] && update-alternatives --remove lsinitrd %{_sbindir}/lsinitrd-dracut || :

%files
%doc README.generic README.modules README.kernel HACKING TODO AUTHORS
%doc README.urpmi
%dir /boot/dracut
%dir %{_datadir}/dracut
%dir %{_var}/lib/dracut
%dir %{_var}/lib/dracut/overlay
%dir %{_prefix}/lib/dracut/modules.d
%dir %{_sysconfdir}/dracut.conf.d
%config(noreplace) %{_sysconfdir}/dracut.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/dracut_log
%attr(0644,root,root) %ghost %config(missingok,noreplace) %{_localstatedir}/log/dracut.log
%{_sysconfdir}/dracut.conf.d/50-dracut-mandriva.conf
/sbin/dracut
%{_sbindir}/dracut
%{_bindir}/dracut
%{_bindir}/initrd-backup.sh
%{_sbindir}/dracut-catimages
%{_sbindir}/dracut-install
%{_sbindir}/lsinitrd-dracut
%{_sbindir}/mkinitrd-dracut
%{_unitdir}/*.service
%{_unitdir}/*/*.service
%{_prefix}/lib/dracut/dracut-install
%{_prefix}/lib/dracut/dracut-version.sh
%{_prefix}/lib/dracut/dracut-functions.sh
%{_prefix}/lib/dracut/dracut-functions
%{_prefix}/lib/dracut/modules.d/*
%{_prefix}/lib/dracut/dracut-initramfs-restore
%{_prefix}/lib/dracut/dracut-logger.sh
%{_mandir}/man1/lsinitrd.1.*
%{_mandir}/man8/dracut*.8*
%{_mandir}/man8/initrd-switch-root.service.8*
%{_mandir}/man8/udevadm-cleanup-db.service.8*
%{_mandir}/man7/dracut.kernel.7*
%{_mandir}/man7/dracut.cmdline.7*
%{_mandir}/man5/dracut.conf.5*


%changelog
* Fri Oct 19 2012 Tomasz Pawel Gajc <tpg@mandriva.org> 024-2
+ Revision: 819042
- reupload
- update to new version 024
- remove duplicate requires on mount
- provide a initd-backup.sh script which should store as a backup current working initrd file and recreates new one
  o just add the script, in next step i'll have to figure out a best mechanism to execute the script on every systemd, dracut on any other core package update
- fix udevadm path
- do not suggest plymouth theme

* Wed Aug 01 2012 Tomasz Pawel Gajc <tpg@mandriva.org> 023-1
+ Revision: 811538
- package new man files
- add buildrequires on asciidoc
- update to new version 023

* Sun Jul 22 2012 Tomasz Pawel Gajc <tpg@mandriva.org> 022-2
+ Revision: 810606
- remove mkinitrd manual, which conflicts with mkinitrd package

* Sun Jul 22 2012 Tomasz Pawel Gajc <tpg@mandriva.org> 022-1
+ Revision: 810597
- update to new version 022
- drop git patches 1010 and 1011
- rediff patch 1002
- update file list

* Fri Jul 20 2012 Tomasz Pawel Gajc <tpg@mandriva.org> 020-8
+ Revision: 810470
- require kmod instead of module-init-tools on mdv 2012
- Patch1011: fix populate script
- fix default image name in theme for mdv 2012

* Sun Jul 08 2012 Tomasz Pawel Gajc <tpg@mandriva.org> 020-6
+ Revision: 808488
- do not fillow symlinks in case of systemctl

* Sun Jul 08 2012 Tomasz Pawel Gajc <tpg@mandriva.org> 020-5
+ Revision: 808469
- Patch 1010: use systemd-udevd.service

* Sun Jul 08 2012 Tomasz Pawel Gajc <tpg@mandriva.org> 020-4
+ Revision: 808465
- fix paths for symlinks

* Sat Jul 07 2012 Bernhard Rosenkraenzer <bero@bero.eu> 020-3
+ Revision: 808444
- This package can't be noarch anymore due to dracut-install

* Sat Jul 07 2012 Tomasz Pawel Gajc <tpg@mandriva.org> 020-2
+ Revision: 808431
- do not load aufs-mount support

* Sat Jul 07 2012 Tomasz Pawel Gajc <tpg@mandriva.org> 020-1
+ Revision: 808430
- update mandriva default config
  o omit loading network module
  o always load these modules pata_acpi ata_generic ahci xhci-hcd
- update to new version 020
- disable patches 1005-1009
- provide compat symlinks to dracut executable
- own directories and config files
- update file list
- update to new version 020

* Sat Jun 02 2012 Per Øyvind Karlsen <peroyvind@mandriva.org> 018-11
+ Revision: 801999
- add provides for 'mkinitrd-command' so that kernel can add a dependency
  that may be satisfied by either mkinitrd or dracut

* Sat Jun 02 2012 Per Øyvind Karlsen <peroyvind@mandriva.org> 018-10
+ Revision: 801956
- provide a versioned mkinitrd to get around kernel depency for now
- remove dependency on plymouth, settle with a suggests on plymouth(system-theme) in stead

* Sun May 13 2012 Tomasz Pawel Gajc <tpg@mandriva.org> 018-9
+ Revision: 798629
- fix patch Patch1007
- Patch1009: install /var/run and /var/lock

* Sun May 13 2012 Tomasz Pawel Gajc <tpg@mandriva.org> 018-7
+ Revision: 798622
- Patch1008: do not remount disk partitions

* Sat May 12 2012 Tomasz Pawel Gajc <tpg@mandriva.org> 018-6
+ Revision: 798413
- Patch1007: check for the right tty and use it

* Mon Apr 30 2012 Tomasz Pawel Gajc <tpg@mandriva.org> 018-5
+ Revision: 794602
- set default initrd compression to xz
- do not load into initrd radeon and nouveau modules

* Sat Apr 28 2012 Tomasz Pawel Gajc <tpg@mandriva.org> 018-4
+ Revision: 794295
- include ahci driver into initrd
- pre requires rpm-helper

* Wed Apr 11 2012 Tomasz Pawel Gajc <tpg@mandriva.org> 018-3
+ Revision: 790329
- install systemd services

* Sat Apr 07 2012 Tomasz Pawel Gajc <tpg@mandriva.org> 018-2
+ Revision: 789681
- fix config file

* Sat Apr 07 2012 Tomasz Pawel Gajc <tpg@mandriva.org> 018-1
+ Revision: 789673
- fix file list
- update to new version 0.18

* Thu Mar 22 2012 Tomasz Pawel Gajc <tpg@mandriva.org> 017-1
+ Revision: 786199
- update to new version 017
- drop all patches from git
- rediff mandriva specific patches

* Tue Feb 07 2012 Oden Eriksson <oeriksson@mandriva.com> 014-2
+ Revision: 771537
- phew, iurt isn't very clever
- try to workaround a silly iurt bug
- sync with dracut-014-81.git20120202.fc17.src.rpm
- rediff some of our patches
- various fixes

* Mon Dec 19 2011 Tomasz Pawel Gajc <tpg@mandriva.org> 014-1
+ Revision: 743757
- update to new version 014
- rediff patch 19
- dracut executables are now in %%{_sbindir}
- fix file list

* Sun Oct 09 2011 Tomasz Pawel Gajc <tpg@mandriva.org> 013-2
+ Revision: 703941
- Obsolete old verions
- pre requires filesystem

* Wed Aug 24 2011 Tomasz Pawel Gajc <tpg@mandriva.org> 013-1
+ Revision: 696536
- update to new version 013
- update links for URLS
- rediff patches 19 and 101
- drop patch 22 not neede at all
- disable patch 100 (needed ony for build iso ?)
- provide better description
- add dash and bash to buildrequires

* Mon Aug 15 2011 Tomasz Pawel Gajc <tpg@mandriva.org> 011-2
+ Revision: 694636
- fix install of files in /etc/ld.so.conf.d (mdv #63914)

* Sat Jul 23 2011 Tomasz Pawel Gajc <tpg@mandriva.org> 011-1
+ Revision: 691214
- update to new version 011
- rediff patches 0, 26 and 100
- disable patches 22 and 101

* Tue Jun 28 2011 Alex Burmashev <burmashev@mandriva.org> 010-6
+ Revision: 687677
- Temporarily enabled livecd patch to boot RC1 images

* Wed Jun 15 2011 Luca Berra <bluca@mandriva.org> 010-5
+ Revision: 685375
- removed P100 (dracut-010-rosa-livecdfix.patch) which broke dracut
- make dracut the default mkinitrd program

* Mon Apr 18 2011 Alex Burmashev <burmashev@mandriva.org> 010-4
+ Revision: 655817
- Fix for dracut initrd creation
- workaround release up
- a very bad workaround

* Mon Apr 18 2011 Anssi Hannula <anssi@mandriva.org> 010-2
+ Revision: 654813
- fix a typo introduced in patch rediff of previous commit

* Sun Apr 17 2011 Tomasz Pawel Gajc <tpg@mandriva.org> 010-1
+ Revision: 654778
- update to new version 010
- rediff patches 5, 22, 26 and 100
- drop patches 23, 24 and 25
- fix file list

* Sun Apr 17 2011 Anssi Hannula <anssi@mandriva.org> 008-6
+ Revision: 654052
- handle gzip compressed KMS kernel modules

* Mon Mar 14 2011 Alex Burmashev <burmashev@mandriva.org> 008-5
+ Revision: 644610
- Fixed aufs mount patch

* Sun Feb 27 2011 Funda Wang <fwang@mandriva.org> 008-4
+ Revision: 640430
- rebuild to obsolete old packages

* Sat Feb 19 2011 Andrey Borzenkov <arvidjaar@mandriva.org> 008-3
+ Revision: 638675
- P25: fix P24 (submitted upstream)

* Sat Feb 19 2011 Andrey Borzenkov <arvidjaar@mandriva.org> 008-2
+ Revision: 638631
- P24: default to UTF-8 on console unless disabled (GIT)
- P23: fix i18n parsing in hostonly mode (GIT)
- P22: create flag if plymouth was started (GIT)
- P19: fix typo

* Thu Feb 17 2011 Andrey Borzenkov <arvidjaar@mandriva.org> 008-1
+ Revision: 638264
- S3: update for new i18n module
- simplify P15

  + Eugeni Dodonov <eugeni@mandriva.com>
    - Update patches to dracut 008 api.
      Drop P18 and P20, no longer needed.

* Wed Jan 26 2011 Eugeni Dodonov <eugeni@mandriva.com> 007-6
+ Revision: 633069
- P21: add support for mounting aufs (Ivan Milov <ivan.milov@rosalab.ru>)
- P100: add support for building live iso images (Andrew Shubar <andrew.shubin@rosalab.ru>)

* Sun Sep 05 2010 Tomasz Pawel Gajc <tpg@mandriva.org> 007-3mdv2011.0
+ Revision: 576017
- Patch20: add path check for rsyslog libraries

* Wed Aug 11 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 007-2mdv2011.0
+ Revision: 569111
- patch19 and source3: fix unicode keymap with new i18n module
- patch18: fix bootchart module installation
- patch1: revert to original behaviour - install when bootchart RPM
  is present
- do not unconditionally enable bootchart
- add source3 - default mandriva config. For now it enabled bootchart
- delete source1, source2 - redundant, already included upstream

* Mon Aug 09 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 007-1mdv2011.0
+ Revision: 568172
- package dracut.kernel(7) man page
- add BuildRequires for new man page generation from XML source
- remove patches 1, 16, 17 - integrated upstream
- new version

* Thu Aug 05 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 006-3mdv2011.0
+ Revision: 566440
- patch17: fix ahci detection in kernel 2.6.35

* Wed Aug 04 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 006-2mdv2011.0
+ Revision: 565664
- patch16: fix modules check in hostonly mode

* Sat Jul 10 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 006-1mdv2011.0
+ Revision: 550022
- new version; rebase patches

* Mon Mar 22 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 005-1mdv2010.1
+ Revision: 526382
- remove patches 2, 999 - merged upstream
- new version

* Fri Mar 19 2010 Frederic Crozat <fcrozat@mandriva.com> 004-6mdv2010.1
+ Revision: 525289
- Add source1/2 : add support for bootchart2

* Sun Mar 07 2010 Luca Berra <bluca@mandriva.org> 004-5mdv2010.1
+ Revision: 515443
- update to latest git
- remove patches merged upstream
- add two patches not yet merged

* Mon Mar 01 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 004-4mdv2010.1
+ Revision: 512870
- patch17: fix boot without resume= (#57924)
- update patch16 with official upstream version

* Mon Mar 01 2010 Tomasz Pawel Gajc <tpg@mandriva.org> 004-3mdv2010.1
+ Revision: 512825
- Patch16: check for multipath existence, if not then die (mdvbz #57919)

  + Andrey Borzenkov <arvidjaar@mandriva.org>
    - change postun for compliance with alternatives policy

* Sat Feb 06 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 004-2mdv2010.1
+ Revision: 501426
- add alternatives for lsinitrd

  + Jani Välimaa <wally@mandriva.org>
    - escape 'uname -r' in README.urpmi

* Tue Feb 02 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 004-1mdv2010.1
+ Revision: 499727
- package new man pages and lsinitrd-dracut
- patch15: mkinitrd-dracut; remove it as source1 (it is now upstream)
- remove patches 1-12: integrated upstream
- new version

* Sun Jan 31 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 003-6mdv2010.1
+ Revision: 498683
- patch14: pass init arguments from commmand line to real init

* Sun Jan 17 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 003-5mdv2010.1
+ Revision: 492577
- patch13: fix firmware loading with current udev

* Sun Jan 10 2010 Luca Berra <bluca@mandriva.org> 003-4mdv2010.1
+ Revision: 488601
- add support for uswsuspend from Andrey
- ensure module scripts are executable

* Sat Jan 09 2010 Luca Berra <bluca@mandriva.org> 003-3mdv2010.1
+ Revision: 487939
- use alternatives for mkinitrd-dracut, and conflict with mkinitrd < mkinitrd-6.0.93-10mnb2
- remove -H from mkinitrd-dracut, it is better left in the configuration file
- modify the default configuration file to enable host-only mode and add some generic ata drivers.
- add console unicode patch from Andrey

* Tue Dec 29 2009 Luca Berra <bluca@mandriva.org> 003-2mdv2010.1
+ Revision: 483256
- split mdv patch, change terminfo and kbd patches in order to push upstream
- install umount when needed
- disable selinux
- fix standard error in emergency shell and set prompt to indicate what stage we are
- include patches from git
 - multipath: supress warnings, if multipath not installed on system
 - cryptroot-ask.sh:  s/==/=/g (bug #542081)
 - plymouth-pretrigger: force initializing of console (bug #526570)

* Mon Dec 28 2009 Luca Berra <bluca@mandriva.org> 003-1mdv2010.1
+ Revision: 483155
- added wrapper to emulate mkinitrd syntax
- honor add_drivers when making an host-only initrd
- add support for compressed kernel modules
- build fixes

  + Tomasz Pawel Gajc <tpg@mandriva.org>
    - update to new version 003

* Thu Nov 12 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 002-4mdv2010.1
+ Revision: 465469
- set requires(pre) on plymouth

* Fri Oct 09 2009 Frederic Crozat <fcrozat@mandriva.com> 002-3mdv2010.0
+ Revision: 456372
- Fix README.urpmi

* Thu Oct 08 2009 Frederic Crozat <fcrozat@mandriva.com> 002-2mdv2010.0
+ Revision: 456028
- Do no rely on old plymouth-theme-mdv

* Fri Sep 18 2009 Frederic Crozat <fcrozat@mandriva.com> 002-1mdv2010.0
+ Revision: 444370
- Release 002
- Remove merged patches

* Mon Sep 07 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 001-2mdv2010.0
+ Revision: 432951
- Patch0: one more fix

* Mon Sep 07 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 001-1mdv2010.0
+ Revision: 432801
- update to new version 001
- Patch0: rediff
- add three patches from Fedora
- update to new version 001

* Sun Aug 30 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 0.9-1mdv2010.0
+ Revision: 422367
- update to new version 0.9
- rediff patch0
- add more critical requires

* Thu Aug 27 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 0.7-2mdv2010.0
+ Revision: 421772
- switch_root is conflicting against util-linux-ng one, so remove it
- Patch0: adapt scripts to mdv specifications
- make it noarch (because switch_root is gone)
- provide REAME.urpmi

* Thu Aug 27 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 0.7-1mdv2010.0
+ Revision: 421733
- import dracut

